@@ -15,13 +15,16 @@
 
 from cbc_sdk.base import (MutableBaseModel, UnrefreshableModel, CreatableModelMixin, NewBaseModel, FacetQuery,
                           PaginatedQuery, QueryBuilder, QueryBuilderSupportMixin, IterableQueryMixin, AsyncQueryMixin)
-from cbc_sdk.platform import PlatformQueryBase
 from cbc_sdk.utils import convert_query_params
 from cbc_sdk.errors import ApiError
+from cbc_sdk.platform.reputation import ReputationOverride
 from copy import deepcopy
+from pathlib import Path
+
 import logging
 import json
 import time
+import os
 
 from cbc_sdk.errors import ServerError
 
@@ -260,9 +263,26 @@ class EnrichedEvent(UnrefreshableModel):
         """
         self._details_timeout = 0
         self._info = None
+        if model_unique_id is not None and initial_data is None:
+            enriched_event_future = cb.select(EnrichedEvent).where(event_id=model_unique_id).execute_async()
+            result = enriched_event_future.result()
+            if len(result) == 1:
+                initial_data = result[0]
         super(EnrichedEvent, self).__init__(cb, model_unique_id=model_unique_id, initial_data=initial_data,
                                             force_init=force_init, full_doc=full_doc)
 
+    @property
+    def process_sha256(self):
+        """Returns a string representation of the SHA256 hash for this process.
+
+        Returns:
+            hash (str): SHA256 hash of the process.
+        """
+        if "process_hash" in self._info:
+            return next((hsh for hsh in self.process_hash if len(hsh) == 64), None)
+        else:
+            return None
+
     def get_details(self, timeout=0, async_mode=False):
         """Requests detailed results.
 
@@ -331,6 +351,40 @@ class EnrichedEvent(UnrefreshableModel):
                 self._info = results[0]
                 return self
 
+    def ban_process_sha256(self, description=""):
+        """Bans the application by adding the process_sha256 to the BLACK_LIST
+
+        Args:
+            description: The justification for why the application was added to the BLACK_LIST
+
+        Returns:
+            ReputationOverride (cbc_sdk.platform.ReputationOverride): ReputationOverride object
+                created in the Carbon Black Cloud
+        """
+        return ReputationOverride.create(self._cb, {
+            "description": description,
+            "override_list": "BLACK_LIST",
+            "override_type": "SHA256",
+            "sha256_hash": self.process_sha256,
+            "filename": Path(self.process_name.replace('\\', os.sep)).name})
+
+    def approve_process_sha256(self, description=""):
+        """Approves the application by adding the process_sha256 to the WHITE_LIST
+
+        Args:
+            description: The justification for why the application was added to the WHITE_LIST
+
+        Returns:
+            ReputationOverride (cbc_sdk.platform.ReputationOverride): ReputationOverride object
+                created in the Carbon Black Cloud
+        """
+        return ReputationOverride.create(self._cb, {
+            "description": description,
+            "override_list": "WHITE_LIST",
+            "override_type": "SHA256",
+            "sha256_hash": self.process_sha256,
+            "filename": Path(self.process_name.replace('\\', os.sep)).name})
+
 
 class EnrichedEventFacet(UnrefreshableModel):
     """Represents an enriched event retrieved by one of the Enterprise EDR endpoints."""
@@ -419,7 +473,7 @@ class EnrichedEventFacet(UnrefreshableModel):
 """Endpoint Standard Queries"""
 
 
-class Query(PaginatedQuery, PlatformQueryBase, QueryBuilderSupportMixin, IterableQueryMixin):
+class Query(PaginatedQuery, QueryBuilderSupportMixin, IterableQueryMixin):
     """Represents a prepared query to the Cb Endpoint Standard server.
 
     This object is returned as part of a `CBCloudAPI.select`
@@ -446,6 +500,9 @@ class Query(PaginatedQuery, PlatformQueryBase, QueryBuilderSupportMixin, Iterabl
 
     def __init__(self, doc_class, cb, query=None):
         """Initialize a Query object."""
+        self._doc_class = doc_class
+        self._cb = cb
+        self._count_valid = False
         super(Query, self).__init__(doc_class, cb, query)
 
         # max batch_size is 5000
