@@ -14,8 +14,9 @@
 """Model and Query Classes for Platform Devices"""
 
 from cbc_sdk.errors import ApiError
-from cbc_sdk.platform import PlatformModel, PlatformQueryBase
-from cbc_sdk.base import QueryBuilder, QueryBuilderSupportMixin, IterableQueryMixin, AsyncQueryMixin
+from cbc_sdk.platform import PlatformModel
+from cbc_sdk.base import (BaseQuery, QueryBuilder, QueryBuilderSupportMixin, CriteriaBuilderSupportMixin,
+                          IterableQueryMixin, AsyncQueryMixin)
 
 import time
 
@@ -173,7 +174,8 @@ class Device(PlatformModel):
 """Device Queries"""
 
 
-class DeviceSearchQuery(PlatformQueryBase, QueryBuilderSupportMixin, IterableQueryMixin, AsyncQueryMixin):
+class DeviceSearchQuery(BaseQuery, QueryBuilderSupportMixin, CriteriaBuilderSupportMixin,
+                        IterableQueryMixin, AsyncQueryMixin):
     """Represents a query that is used to locate Device objects."""
     VALID_OS = ["WINDOWS", "ANDROID", "MAC", "IOS", "LINUX", "OTHER"]
     VALID_STATUSES = ["PENDING", "REGISTERED", "UNINSTALLED", "DEREGISTERED",
@@ -182,6 +184,7 @@ class DeviceSearchQuery(PlatformQueryBase, QueryBuilderSupportMixin, IterableQue
                       "DELETED", "LIVE"]
     VALID_PRIORITIES = ["LOW", "MEDIUM", "HIGH", "MISSION_CRITICAL"]
     VALID_DIRECTIONS = ["ASC", "DESC"]
+    VALID_DEPLOYMENT_TYPES = ["ENDPOINT", "WORKLOAD"]
 
     def __init__(self, doc_class, cb):
         """
@@ -191,27 +194,17 @@ class DeviceSearchQuery(PlatformQueryBase, QueryBuilderSupportMixin, IterableQue
             doc_class (class): The model class that will be returned by this query.
             cb (BaseAPI): Reference to API object used to communicate with the server.
         """
-        super().__init__(doc_class, cb)
+        self._doc_class = doc_class
+        self._cb = cb
+        self._count_valid = False
+        super(DeviceSearchQuery, self).__init__()
+
         self._query_builder = QueryBuilder()
         self._criteria = {}
         self._time_filter = {}
         self._exclusions = {}
         self._sortcriteria = {}
 
-    def _update_criteria(self, key, newlist):
-        """
-        Updates the criteria being collected for a query.
-
-        Assumes the specified criteria item is defined as a list; the list passed in will be set as the value for
-        this criteria item, or appended to the existing one if there is one.
-
-        Args:
-            key (str): The key for the criteria item to be set.
-            newlist (list): List of values to be set for the criteria item.
-        """
-        oldlist = self._criteria.get(key, [])
-        self._criteria[key] = oldlist + newlist
-
     def _update_exclusions(self, key, newlist):
         """
         Updates the exclusion criteria being collected for a query.
@@ -411,6 +404,24 @@ class DeviceSearchQuery(PlatformQueryBase, QueryBuilderSupportMixin, IterableQue
         self._sortcriteria = {"field": key, "order": direction}
         return self
 
+    def set_deployment_type(self, deployment_type):
+        """
+        Restricts the devices that this query is performed on to the specified deployment types.
+
+        Args:
+            deployment_type (list): List of deployment types to restrict search to.
+
+        Returns:
+            DeviceSearchQuery: This instance.
+
+        Raises:
+            ApiError: If invalid deployment type values are passed in the list.
+        """
+        if not all((type in DeviceSearchQuery.VALID_DEPLOYMENT_TYPES) for type in deployment_type):
+            raise ApiError("invalid deployment_type specified")
+        self._update_criteria("deployment_type", deployment_type)
+        return self
+
     def _build_request(self, from_row, max_rows):
         """
         Creates the request body for an API call.
